This is a much simpler implementation of the tools found in the
PostcodesioR R package, intended for use with the networkMap()
function.
See also
The PostcodesioR package at
https://github.com/ropensci/PostcodesioR/
Examples
# convert a UK postcode
convertPostcode("SW1A1AA")
#> $lat
#> [1] 51.50101
#>
#> $lng
#> [1] -0.141563
#>
#> $postcode
#> [1] "SW1A 1AA"
#>
if (FALSE) { # \dontrun{
# use with `networkMap()`
palace <- convertPostcode("SW1A1AA")
networkMap("aurn", lat = palace$lat, lng = palace$lng, max_dist = 10)
} # }